@@ -41,7 +41,6 @@ func TestPolicyAdmx(t *testing.T) {
 		"Error on daemon not responding": {arg: "lts-only", daemonNotStarted: true, wantErr: true},
 	}
 	for name, tc := range tests {
-		tc := tc
 		t.Run(name, func(t *testing.T) {
 			dbusAnswer(t, tc.systemAnswer)
 
@@ -120,7 +119,6 @@ func TestPolicyApplied(t *testing.T) {
 		"Error on daemon not responding":                            {daemonNotStarted: true, wantErr: true},
 	}
 	for name, tc := range tests {
-		tc := tc
 		t.Run(name, func(t *testing.T) {
 			if tc.systemAnswer == "" {
 				tc.systemAnswer = "polkit_yes"
@@ -215,8 +213,11 @@ func TestPolicyUpdate(t *testing.T) {
 		addPaths            []string
 		readOnlyDirs        []string
 		winbindMockBehavior string
+		krb5MockBehavior    string
 		purge               bool
 		missingCertmonger   bool
+		noExportKrb5cc      bool
+		detectCachedTicket  bool
 
 		wantErr bool
 	}{
@@ -228,6 +229,33 @@ func TestPolicyUpdate(t *testing.T) {
 			backend:   "winbind",
 			initState: "localhost-uptodate",
 		},
+		"Current user, KRB5CCNAME is not exported but present": {
+			initState:          "localhost-uptodate",
+			noExportKrb5cc:     true,
+			detectCachedTicket: true,
+			krb5MockBehavior:   "return_ccache:%s",
+		},
+		"Current user, libkrb5 not used if KRB5CCNAME is present": {
+			initState:          "localhost-uptodate",
+			detectCachedTicket: true,
+			krb5MockBehavior:   "return_ccache:%s/maybebadvalue",
+		},
+		"Current user, libkrb5 not used if setting not enabled": {
+			initState:        "localhost-uptodate",
+			krb5MockBehavior: "return_ccache:%s/maybebadvalue",
+		},
+		"Current user, librkb5 returns error but symlink is present": {
+			initState:          "localhost-uptodate",
+			detectCachedTicket: true,
+			noExportKrb5cc:     true,
+			krb5MockBehavior:   "return_empty_ccache",
+			krb5ccNamesState: []krb5ccNamesWithState{
+				{
+					src:          currentUser + ".krb5",
+					adsysSymlink: currentUser,
+				},
+			},
+		},
 		"Other user, first time": {
 			args:       []string{"userintegrationtest@example.com", "userintegrationtest@example.com.krb5"},
 			initState:  "localhost-uptodate",
@@ -871,6 +899,27 @@ func TestPolicyUpdate(t *testing.T) {
 			},
 			wantErr: true,
 		},
+		// Krb5 library error cases
+		"Error when libkrb5 ccache not present on disk": {
+			initState:          "localhost-uptodate",
+			noExportKrb5cc:     true,
+			detectCachedTicket: true,
+			krb5MockBehavior:   "return_ccache:%s/not_present",
+			wantErr:            true,
+		},
+		"Error when libkrb5 returns null value": {
+			initState:          "localhost-uptodate",
+			noExportKrb5cc:     true,
+			detectCachedTicket: true,
+			krb5MockBehavior:   "return_null_ccache",
+			wantErr:            true,
+		},
+		"Error when cached ticket setting not enabled": {
+			initState:        "localhost-uptodate",
+			noExportKrb5cc:   true,
+			krb5MockBehavior: "return_ccache:%s",
+			wantErr:          true,
+		},
 		// Incompatible options
 		"Error on all and specific user requested": {
 			args:       []string{"--all", "userintegrationtest@example.com", "userintegrationtest@example.com.krb5"},
@@ -943,7 +992,6 @@ func TestPolicyUpdate(t *testing.T) {
 		},
 	}
 	for name, tc := range tests {
-		tc := tc
 		t.Run(name, func(t *testing.T) {
 			if tc.systemAnswer == "" {
 				tc.systemAnswer = "polkit_yes"
@@ -979,6 +1027,9 @@ func TestPolicyUpdate(t *testing.T) {
 				tc.backend = "sssd"
 			}
 
+			if tc.winbindMockBehavior == "" {
+				tc.winbindMockBehavior = "integration_tests"
+			}
 			t.Setenv("ADSYS_WBCLIENT_BEHAVIOR", tc.winbindMockBehavior)
 
 			// Create fake certmonger and cepces binaries for the certificate manager
@@ -1075,10 +1126,19 @@ func TestPolicyUpdate(t *testing.T) {
 				} else {
 					tc.krb5ccname = fmt.Sprintf("FILE:%s/%s", krb5dir, tc.krb5ccname)
 				}
-				t.Setenv("KRB5CCNAME", tc.krb5ccname)
+				if !tc.noExportKrb5cc {
+					t.Setenv("KRB5CCNAME", tc.krb5ccname)
+				}
 			}
 
-			conf := createConf(t, confWithAdsysDir(adsysDir), confWithBackend(tc.backend))
+			if tc.krb5MockBehavior != "" {
+				if strings.Contains(tc.krb5MockBehavior, "return_ccache") {
+					tc.krb5MockBehavior = fmt.Sprintf(tc.krb5MockBehavior, tc.krb5ccname)
+				}
+				t.Setenv("ADSYS_KRB5_BEHAVIOR", tc.krb5MockBehavior)
+			}
+
+			conf := createConf(t, confWithAdsysDir(adsysDir), confWithBackend(tc.backend), confDetectCachedTicket(tc.detectCachedTicket))
 			if tc.sssdConf != "" {
 				content, err := os.ReadFile(conf)
 				require.NoError(t, err, "Setup: can’t read configuration file")
@@ -1110,7 +1170,7 @@ func TestPolicyUpdate(t *testing.T) {
 			require.NoError(t, err, "client should exit with no error")
 
 			goldenPath := testutils.GoldenPath(t)
-			update := testutils.Update()
+			update := testutils.UpdateEnabled()
 			testutils.CompareTreesWithFiltering(t, filepath.Join(adsysDir, "dconf"), filepath.Join(goldenPath, "dconf"), update)
 			testutils.CompareTreesWithFiltering(t, filepath.Join(adsysDir, "sudoers.d"), filepath.Join(goldenPath, "sudoers.d"), update)
 			testutils.CompareTreesWithFiltering(t, filepath.Join(adsysDir, "polkit-1"), filepath.Join(goldenPath, "polkit-1"), update)
@@ -1152,7 +1212,6 @@ func TestPolicyDebugScriptDump(t *testing.T) {
 		"Error on daemon not responding for cert-autoenroll": {script: "cert-autoenroll", cmdName: "cert-autoenroll-script", path: "internal/policies/certificate", daemonNotStarted: true, wantErr: true},
 	}
 	for name, tc := range tests {
-		tc := tc
 		t.Run(name, func(t *testing.T) {
 			dbusAnswer(t, tc.systemAnswer)
 
@@ -1185,6 +1244,76 @@ func TestPolicyDebugScriptDump(t *testing.T) {
 	}
 }
 
+func TestPolicyDebugTicketPath(t *testing.T) {
+	tests := map[string]struct {
+		username string
+
+		configDisabled bool
+		pathNotPresent bool
+		pathIsDir      bool
+
+		wantOut string
+		wantErr bool
+	}{
+		"Return path for current explicit user": {},
+		"Return path for current implicit user": {username: "-"},
+
+		// No-op cases (return no error and no output)
+		"No-op when path not present on disk":        {pathNotPresent: true},
+		"No-op when detect_cached_ticket is not set": {configDisabled: true},
+
+		// Error cases
+		"Error when passed an invalid user":   {username: "invaliduser", wantErr: true},
+		"Error if ticket path is a directory": {pathIsDir: true, wantErr: true},
+	}
+	for name, tc := range tests {
+		t.Run(name, func(t *testing.T) {
+			// Empty username means current user
+			if tc.username == "" {
+				u, err := user.Current()
+				require.NoError(t, err, "Setup: could not get current user")
+				tc.username = u.Username
+			}
+			// "-" username means empty argument, current user is inferred
+			if tc.username == "-" {
+				tc.username = ""
+			}
+
+			// Ensure we start and finish the test with a clean slate on disk
+			uid := os.Getuid()
+			krb5ccname := filepath.Join(os.TempDir(), fmt.Sprintf("krb5cc_%d", uid))
+			err := os.RemoveAll(krb5ccname)
+			require.NoError(t, err, "Setup: could not remove ticket path")
+			t.Cleanup(func() {
+				err := os.RemoveAll(krb5ccname)
+				require.NoError(t, err, "Teardown: could not remove ticket path")
+			})
+
+			if tc.pathIsDir {
+				err := os.MkdirAll(krb5ccname, 0700)
+				require.NoError(t, err, "Setup: could not create ticket directory")
+			} else if !tc.pathNotPresent {
+				err := os.WriteFile(krb5ccname, []byte("Some ticket content"), 0600)
+				require.NoError(t, err, "Setup: could not write ticket content")
+				tc.wantOut = krb5ccname + "\n"
+			}
+
+			if tc.configDisabled {
+				tc.wantOut = ""
+			}
+
+			conf := createConf(t, confDetectCachedTicket(!tc.configDisabled))
+			out, err := runClient(t, conf, "policy", "debug", "ticket-path", tc.username)
+			if tc.wantErr {
+				require.Error(t, err, "command should exit with an error")
+				return
+			}
+			require.NoError(t, err, "command should exit with no error")
+			require.Equal(t, tc.wantOut, out, "command output should match")
+		})
+	}
+}
+
 func modifyAndAddUsers(t *testing.T, new string, users ...string) (passwd string) {
 	t.Helper()
 	dest := filepath.Join(t.TempDir(), "passwd")
@@ -1240,6 +1369,7 @@ func setupSubprocessForTest(t *testing.T, currentUser string, otherUsers ...stri
 	require.NoError(t, err, "libnss-wrapper is not installed on disk, either skip integration tests or install it")
 
 	mockWinbindLibPath := testutils.BuildWinbindMock(t, filepath.Join(rootProjectDir, "internal/ad/backends/winbind"))
+	mockKrb5LibPath := testutils.BuildKrb5Mock(t, filepath.Join(rootProjectDir, "internal/ad"))
 
 	var subArgs []string
 	// We are going to only reexec ourself: only take options (without -run)
@@ -1285,7 +1415,7 @@ func setupSubprocessForTest(t *testing.T, currentUser string, otherUsers ...stri
 		fmt.Sprintf("PYTHONPATH=%s", admock),
 
 		// override user and host database
-		fmt.Sprintf("LD_PRELOAD=libnss_wrapper.so:%s", mockWinbindLibPath),
+		fmt.Sprintf("LD_PRELOAD=libnss_wrapper.so:%s:%s", mockWinbindLibPath, mockKrb5LibPath),
 		fmt.Sprintf("NSS_WRAPPER_PASSWD=%s", passwd),
 		"NSS_WRAPPER_GROUP=/etc/group",
 	)
