@@ -40,8 +40,6 @@ func TestAdsysdRunScripts(t *testing.T) {
 	}
 
 	for name, tc := range tests {
-		tc := tc
-		name := name
 		t.Run(name, func(t *testing.T) {
 			t.Parallel()
 
@@ -85,7 +83,7 @@ func TestAdsysdRunScripts(t *testing.T) {
 
 			// Get and compare oracle file to check order
 			src := filepath.Join(p, "golden")
-			testutils.CompareTreesWithFiltering(t, src, testutils.GoldenPath(t), testutils.Update())
+			testutils.CompareTreesWithFiltering(t, src, testutils.GoldenPath(t), testutils.UpdateEnabled())
 		})
 	}
 }
