@@ -9,6 +9,7 @@ import (
 	"os"
 	"path/filepath"
 	"runtime"
+	"slices"
 	"strings"
 	"testing"
 	"time"
@@ -17,7 +18,6 @@ import (
 	"github.com/stretchr/testify/require"
 	"github.com/ubuntu/adsys/cmd/adwatchd/commands"
 	"github.com/ubuntu/adsys/internal/testutils"
-	"golang.org/x/exp/slices"
 	"gopkg.in/ini.v1"
 )
 
@@ -48,8 +48,6 @@ func TestServiceStateChange(t *testing.T) {
 		"uninstall and restart":    {sequence: []string{"uninstall", "stop"}, wantErrAt: []int{1}},
 	}
 	for name, tc := range tests {
-		tc := tc
-		name := name
 		t.Run(name, func(t *testing.T) {
 			var err error
 
@@ -240,8 +238,6 @@ func TestServiceConfigFlagUsage(t *testing.T) {
 		"install": {wantConfig: true},
 	}
 	for name, tc := range tests {
-		tc := tc
-		name := name
 		t.Run(name, func(t *testing.T) {
 			r, w, err := os.Pipe()
 			require.NoError(t, err, "Setup: pipe shouldn't fail")
