@@ -1,3 +1,4 @@
+// Package main is the adwatchd entry point to start the Windows or Linux service.
 package main
 
 import (
@@ -9,11 +10,12 @@ import (
 	log "github.com/sirupsen/logrus"
 	"github.com/ubuntu/adsys/cmd/adwatchd/commands"
 	"github.com/ubuntu/adsys/internal/consts"
-	"github.com/ubuntu/adsys/internal/i18n"
+	"github.com/ubuntu/adsys/po"
+	"github.com/ubuntu/go-i18n"
 )
 
 func run(a *commands.App) int {
-	i18n.InitI18nDomain(consts.TEXTDOMAIN)
+	i18n.InitI18nDomain(consts.TEXTDOMAIN, po.Files)
 	defer installSignalHandler(a)()
 	log.SetFormatter(&log.TextFormatter{
 		DisableLevelTruncation: true,
