@@ -4,12 +4,12 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/leonelquinteros/gotext"
 	"github.com/sirupsen/logrus"
 	"github.com/ubuntu/adsys"
 	"github.com/ubuntu/adsys/internal/grpc/contextidler"
 	"github.com/ubuntu/adsys/internal/grpc/interceptorschain"
 	log "github.com/ubuntu/adsys/internal/grpc/logstreamer"
-	"github.com/ubuntu/adsys/internal/i18n"
 	"github.com/ubuntu/decorate"
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/credentials/insecure"
@@ -23,7 +23,7 @@ type AdSysClient struct {
 
 // NewClient connect to the socket and returns a new AdSysClient.
 func NewClient(socket string, timeout time.Duration) (c *AdSysClient, err error) {
-	defer decorate.OnError(&err, i18n.G("can't create client for service"))
+	defer decorate.OnError(&err, gotext.Get("can't create client for service"))
 
 	conn, err := grpc.Dial(fmt.Sprintf("unix:%s", socket), grpc.WithTransportCredentials(insecure.NewCredentials()),
 		grpc.WithStreamInterceptor(interceptorschain.StreamClient(
