@@ -1,7 +1,9 @@
 // Package consts defines the constants used by the project
 package consts
 
-import log "github.com/sirupsen/logrus"
+import (
+	log "github.com/sirupsen/logrus"
+)
 
 var (
 	// Version is the version of the executable.
@@ -36,6 +38,9 @@ const (
 	// DefaultServiceTimeout is the default time in seconds without any active request before the service exits.
 	DefaultServiceTimeout = 120
 
+	// DefaultGpoListTimeout is the default time to wait for the GPO list subcommand to finish.
+	DefaultGpoListTimeout = 10
+
 	// DistroID is the distro ID which can be overridden at build time.
 	DistroID = "Ubuntu"
 )
